# scranking

scranking is a python library that display ranking of the college swimmer

[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)

![GitHub issues](https://img.shields.io/github/issues/joon0110/scranking)
[![Build Status](https://github.com/joon0110/scranking/workflows/Build%20Status/badge.svg?branch=main)](https://github.com/joon0110/scranking/actions/workflows/build.yml)
[![codecov](https://codecov.io/gh/joon0110/scranking/branch/main/graph/badge.svg)](https://codecov.io/gh/joon0110/scranking)

## Overview

Scranking is a library that scrapes data from a website such as [swimcloud](https://www.swimcloud.com/swimmer/549377/), which is website that shows times and ranking of the college swimmer. 

The library will allow users to simpily type the URL and get all the neccessary information of that swimmer.

## Install

Install using 'pip install scranking' in the command line.